# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - SVGChart

    @copyright: 2011 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinMoin.action import cache
from MoinMoin import wikiutil
from SVGChartSupport import get_chart

Dependencies = ["pages"]

# Parser support.

class Parser:

    "Format CSV-like data as an SVG chart."

    extensions = [".csv"]

    def __init__(self, raw, request, **kw):

        """
        Initialise the parser with the given 'raw' data, 'request' and any
        keyword arguments that may have been supplied.
        """

        self.raw = raw
        self.request = request
        self.data = [row.split() for row in raw.split("\n")]

        attrs, msg = wikiutil.parseAttributes(request, kw.get("format_args", ""))

        # The attributes returned from the formatting arguments are encoded like
        # strings.

        self.xorigin = float((attrs.get("xorigin") or '"0"')[1:-1])
        self.yorigin = float((attrs.get("yorigin") or '"0"')[1:-1])

    def format(self, fmt):

        "Format a chart using the given formatter 'fmt'."

        request = self.request
        page = request.page
        _ = request.getText

        # NOTE: Store and retrieve the width and height.

        cache_key = cache.key(request, itemname=page.page_name, content="%s,%s,%s" % (self.xorigin, self.yorigin, self.raw))
        if not cache.exists(request, cache_key):
            chart = get_chart(self.data, xorigin=self.xorigin, yorigin=self.yorigin,
                styles_url="%s/%s/css/svgchart.css" % (request.cfg.url_prefix_static, request.theme.name))
            cache.put(request, cache_key, chart, content_type="image/svg+xml")

        request.write(fmt.div(1, css_class="svgchart"))
        request.write(fmt.transclusion(1, data=cache.url(request, cache_key)))
        request.write(fmt.text(_("SVG chart of CSV data.")))
        request.write(fmt.transclusion(0))
        request.write(fmt.div(0))

# vim: tabstop=4 expandtab shiftwidth=4
